local _G = _G
module(...)
at_most = {
	name = "At most",
	tag = "synergy_group",
	order = 5,
	description = "State depends on problems thresholds",
	hint = "Group threshold state",
	rule = function(items, wr_threshold, cr_threshold, unit)
		if wr_threshold >= cr_threshold then
			return {{ status = 3, msg = "Rule is not properly configured. CRITICAL threshold must be greater than WARNING treshold." }}
		end
		local c_pr = 0 --count of problems elements
		local c_ok = 0
		local c_wr = 0
		local c_cr = 0
		local c_un = 0
		local n = 0
		local res_st = 0
		local res_msg = "Problem count: %s. Got %s OK(s), %s WARNING(s), %s CRITICAL(s), %s UNKNOWN(s)"
		for i,value in _G.ipairs(items) do
			if value.status > 0 then
				c_pr = c_pr + 1
				if value.status == 1 then c_wr = c_wr + 1
				elseif value.status == 2 then c_cr = c_cr + 1
				else c_un = c_un + 1
				end
			else
				c_ok = c_ok + 1
			end
			n = n + 1
		end
		if n == 0 then return {{ status = 3, msg = "No state, default state UNKNOWN"}} end
		if unit == "%" then
			local P_pr, P_ok, P_wr, P_cr, P_un
			P_pr= _G.math.ceil(100*c_pr/n)
			P_ok =_G.math.ceil(100*c_ok/n)
			P_wr =_G.math.ceil(100*c_wr/n)
			P_cr =_G.math.ceil(100*c_cr/n)
			P_un =_G.math.ceil(100*c_un/n)
			if P_pr >= cr_threshold then res_st = 2
			elseif P_pr >= wr_threshold then res_st = 1
			end
			res_msg = _G.string.format(res_msg, P_pr.."%", P_ok.."%", P_wr.."%", P_cr.."%", P_un.."%")
		else
			if c_pr >= cr_threshold then res_st = 2
			elseif c_pr >= wr_threshold then res_st = 1
			end
			res_msg = _G.string.format(res_msg, c_pr, c_ok, c_wr, c_cr, c_un)
		end
		return {{ status = res_st, msg = res_msg }}
	end,
	params = {
		{
			validation = {
				required = true,
				number = true,
				lt = { true, "cr_threshold", "CRITICAL threshold" },
				percent = true,
				min = { 0 }
			},
			name = "wr_threshold",
			label = "WARNING threshold",
			type = "number",
			hint = "Count of problems to become WARNING"
		},
		{
			validation = {
				required = true,
				number = true,
				gt = { true, "wr_threshold", "WARNING threshold" },
				percent = true,
				min = { 0 }
			},
			name = "cr_threshold",
			label = "CRITICAL threshold",
			type = "number",
			hint = "Count of problems to become CRITICAL"
		},
		{
			validation = {
				required = true
			},
			name = "unit",
			label = "Unit",
			type = "enum",
			hint = "Unit for the above value (percentage or actual number)",
			values = {"%", "num"}
		}
	}
}
